@@ -1,6 +1,7 @@
 from .__about__ import __version__
 from ._grid import Grid2D, Grid3D, TraveltimeGrid2D, TraveltimeGrid3D
 from ._helpers import get_num_threads, set_num_threads
+from ._io import grid_to_meshio, ray_to_meshio
 from ._solver import Eikonal2D, Eikonal3D
 
 __all__ = [
@@ -12,5 +13,7 @@ __all__ = [
     "TraveltimeGrid3D",
     "get_num_threads",
     "set_num_threads",
+    "grid_to_meshio",
+    "ray_to_meshio",
     "__version__",
 ]
