@@ -7,9 +7,9 @@ def jitted(*args, **kwargs):
         {
             "nopython": True,
             "nogil": True,
-            # Disable fast-math flag "nnan"
+            # Disable fast-math flag "nnan" and "reassoc"
             # <https://llvm.org/docs/LangRef.html#fast-math-flags>
-            "fastmath": {"ninf", "nsz", "arcp", "contract", "afn", "reassoc"},
+            "fastmath": {"ninf", "nsz", "arcp", "contract", "afn"},
             # "fastmath": True,
             # "boundscheck": False,
             "cache": True,
