@@ -1,4 +1,4 @@
-import numpy
+import numpy as np
 from numba import prange
 
 from .._common import dist2d, jitted, norm2d
@@ -19,20 +19,20 @@ def _ray2d(z, x, zgrad, xgrad, zend, xend, zsrc, xsrc, stepsize, max_step, honor
     if honor_grid:
         nz, nx = len(z), len(x)
 
-        i = numpy.searchsorted(z, zend, side="right") - 1
-        j = numpy.searchsorted(x, xend, side="right") - 1
+        i = np.searchsorted(z, zend, side="right") - 1
+        j = np.searchsorted(x, xend, side="right") - 1
         zmin = z[max(i - 1, 0)] if zend == z[i] else z[i]
         xmin = x[max(j - 1, 0)] if xend == x[j] else x[j]
-        lower = numpy.array([zmin, xmin])
-        upper = numpy.array([z[min(i + 1, nz - 1)], x[min(j + 1, nx - 1)]])
+        lower = np.array([zmin, xmin])
+        upper = np.array([z[min(i + 1, nz - 1)], x[min(j + 1, nx - 1)]])
 
-        isrc = numpy.searchsorted(z, zsrc, side="right") - 1
-        jsrc = numpy.searchsorted(x, xsrc, side="right") - 1
+        isrc = np.searchsorted(z, zsrc, side="right") - 1
+        jsrc = np.searchsorted(x, xsrc, side="right") - 1
 
     count = 1
-    pcur = numpy.array([zend, xend], dtype=numpy.float64)
-    delta = numpy.empty(2, dtype=numpy.float64)
-    ray = numpy.empty((max_step, 2), dtype=numpy.float64)
+    pcur = np.array([zend, xend], dtype=np.float64)
+    delta = np.empty(2, dtype=np.float64)
+    ray = np.empty((max_step, 2), dtype=np.float64)
     ray[0] = pcur.copy()
     while dist2d(zsrc, xsrc, pcur[0], pcur[1]) >= stepsize:
         gz = interp2d(z, x, zgrad, pcur)
@@ -55,11 +55,11 @@ def _ray2d(z, x, zgrad, xgrad, zend, xend, zsrc, xsrc, stepsize, max_step, honor
 
             if fac < 1.0:
                 # Handle precision issues due to fac
-                pcur[0] = numpy.round(pcur[0], 8)
-                pcur[1] = numpy.round(pcur[1], 8)
+                pcur[0] = np.round(pcur[0], 8)
+                pcur[1] = np.round(pcur[1], 8)
 
-                i = numpy.searchsorted(z, pcur[0], side="right") - 1
-                j = numpy.searchsorted(x, pcur[1], side="right") - 1
+                i = np.searchsorted(z, pcur[0], side="right") - 1
+                j = np.searchsorted(x, pcur[1], side="right") - 1
                 lower[0] = z[max(i - 1, 0)] if pcur[0] == z[i] else z[i]
                 lower[1] = x[max(j - 1, 0)] if pcur[1] == x[j] else x[j]
                 upper[0] = z[i + 1]
@@ -82,7 +82,7 @@ def _ray2d(z, x, zgrad, xgrad, zend, xend, zsrc, xsrc, stepsize, max_step, honor
         if count >= max_step:
             raise RuntimeError("maximum number of steps reached")
 
-    ray[count] = numpy.array([zsrc, xsrc], dtype=numpy.float64)
+    ray[count] = np.array([zsrc, xsrc], dtype=np.float64)
 
     return ray, count
 
@@ -93,8 +93,8 @@ def _ray2d_vectorized(
 ):
     """Perform ray-tracing in parallel for different points."""
     n = len(zend)
-    rays = numpy.empty((n, max_step, 2), dtype=numpy.float64)
-    counts = numpy.empty(n, dtype=numpy.int32)
+    rays = np.empty((n, max_step, 2), dtype=np.float64)
+    counts = np.empty(n, dtype=np.int32)
     for i in prange(n):
         rays[i], counts[i] = _ray2d(
             z,
