@@ -6,9 +6,9 @@ from .._interp import interp3d
 from ._common import shrink
 
 
-@jitted(
-    "Tuple((f8[:, :], i4))(f8[:], f8[:], f8[:], f8[:, :, :], f8[:, :, :], f8[:, :, :], f8, f8, f8, f8, f8, f8, f8, i4, b1)"
-)
+# @jitted(
+#     "Tuple((f8[:, :], i4))(f8[:], f8[:], f8[:], f8[:, :, :], f8[:, :, :], f8[:, :, :], f8, f8, f8, f8, f8, f8, f8, i4, b1)"
+# )
 def _ray3d(
     z,
     x,
@@ -117,7 +117,7 @@ def _ray3d(
     return ray, count
 
 
-@jitted(parallel=True)
+# @jitted(parallel=True)
 def _ray3d_vectorized(
     z,
     x,
@@ -161,7 +161,7 @@ def _ray3d_vectorized(
     return rays, counts
 
 
-@jitted
+# @jitted
 def ray3d(z, x, y, zgrad, xgrad, ygrad, p, src, stepsize, max_step, honor_grid=False):
     """Perform ray-tracing."""
     if p.ndim == 1:
