@@ -26,7 +26,15 @@ def test_solve(sources, tref):
     (
         ([0.0, 0.0], 1.0),
         ([-1.0, -1.0], numpy.nan),
-        ([[0.0, 0.0], [15.0, 0.0], [15.0, 15.0], [0.0, 15.0],], numpy.ones(4)),
+        (
+            [
+                [0.0, 0.0],
+                [15.0, 0.0],
+                [15.0, 15.0],
+                [0.0, 15.0],
+            ],
+            numpy.ones(4),
+        ),
     ),
 )
 def test_call(points, vref):
