@@ -1,7 +1,11 @@
+from copy import deepcopy
+
 import numpy
 import pytest
 from helpers import allclose, eik3d
 
+eik3d_copy = deepcopy(eik3d)
+
 
 @pytest.mark.parametrize(
     "sources, tref",
@@ -39,3 +43,18 @@ def test_solve(sources, tref):
 )
 def test_call(points, vref):
     allclose(vref, points, lambda x: eik3d(x))
+
+
+def test_resample():
+    eik3d = deepcopy(eik3d_copy)
+    nz, nx, ny = eik3d.shape
+    eik3d.resample((nz * 2, nx * 2, ny * 2))
+
+    assert eik3d.grid.sum() == nz * nx * ny * 8.0
+
+
+def test_smooth():
+    eik2d = deepcopy(eik3d_copy)
+    eik2d.smooth(1.0)
+
+    assert eik2d.grid.sum() == eik3d.grid.size
